@@ -194,7 +194,7 @@ instance Default McpToolsListRequestData where
 data McpToolsCallRequestDataParams =
   McpToolsCallRequestDataParams {
     _nameMcpToolsCallRequestDataParams :: String
-  , _argumentsMcpToolsCallRequestDataParams  :: RawJsonByteString
+  , _argumentsMcpToolsCallRequestDataParams :: RawJsonByteString
   } deriving (Show, Read, Eq)
 
 $(deriveJSON defaultOptions {fieldLabelModifier = dropDataName "McpToolsCallRequestDataParams", omitNothingFields = True} ''McpToolsCallRequestDataParams)
@@ -604,6 +604,12 @@ data McpToolsCallResponseResultContent =
   McpToolsCallResponseResultContent {
     _typeMcpToolsCallResponseResultContent :: String
   , _textMcpToolsCallResponseResultContent :: String
+  }
+  | 
+  McpToolsCallResponseResultImageContent {
+    _typeMcpToolsCallResponseResultContent :: String
+  , _dataMcpToolsCallResponseResultContent :: String
+  , _mimeTypeToolsCallResponseResultContent :: String
   } deriving (Show, Read, Eq)
 
 $(deriveJSON defaultOptions {fieldLabelModifier = dropDataName "McpToolsCallResponseResultContent", omitNothingFields = True} ''McpToolsCallResponseResultContent)
@@ -1154,6 +1160,65 @@ getJsonRpcCmdRunCommand :: CmdRunCommand -> JsonRpcRequest
 getJsonRpcCmdRunCommand (EchoCmdRunCommand    d) = d^.jsonrpcEchoCmdRunCommandData
 getJsonRpcCmdRunCommand (DefaultCmdRunCommand d) = d^.jsonrpcDefaultCmdRunCommandData
 
+
+--------------------------------------------------------------------------------
+-- |
+--
+data EchoFileSystemCommandData =
+  EchoFileSystemCommandData {
+    _jsonrpcEchoFileSystemCommandData :: JsonRpcRequest
+  , _valueEchoFileSystemCommandData   :: String
+  } deriving (Show, Read, Eq)
+
+makeLenses ''EchoFileSystemCommandData
+
+-- |
+--
+data WriteFileFileSystemCommandData =
+  WriteFileFileSystemCommandData {
+    _jsonrpcWriteFileFileSystemCommandData   :: JsonRpcRequest
+  , _argumentsWriteFileFileSystemCommandData :: RawJsonByteString
+  } deriving (Show, Read, Eq)
+
+makeLenses ''WriteFileFileSystemCommandData
+
+-- |
+--
+data ReadFileFileSystemCommandData =
+  ReadFileFileSystemCommandData {
+    _jsonrpcReadFileFileSystemCommandData   :: JsonRpcRequest
+  , _argumentsReadFileFileSystemCommandData :: RawJsonByteString
+  } deriving (Show, Read, Eq)
+
+makeLenses ''ReadFileFileSystemCommandData
+
+-- |
+--
+data ListDirFileSystemCommandData =
+  ListDirFileSystemCommandData {
+    _jsonrpcListDirFileSystemCommandData   :: JsonRpcRequest
+  , _argumentsListDirFileSystemCommandData :: RawJsonByteString
+  } deriving (Show, Read, Eq)
+
+makeLenses ''ListDirFileSystemCommandData
+
+-- |
+--
+data FileSystemCommand =
+    EchoFileSystemCommand EchoFileSystemCommandData
+  | ListDirFileSystemCommand ListDirFileSystemCommandData
+  | ReadFileFileSystemCommand ReadFileFileSystemCommandData
+  | WriteFileFileSystemCommand WriteFileFileSystemCommandData
+  deriving (Show, Read, Eq)
+
+-- |
+--
+getJsonRpcFileSystemCommand :: FileSystemCommand -> JsonRpcRequest
+getJsonRpcFileSystemCommand (EchoFileSystemCommand d)      = d^.jsonrpcEchoFileSystemCommandData
+getJsonRpcFileSystemCommand (ListDirFileSystemCommand d)   = d^.jsonrpcListDirFileSystemCommandData
+getJsonRpcFileSystemCommand (ReadFileFileSystemCommand d)  = d^.jsonrpcReadFileFileSystemCommandData
+getJsonRpcFileSystemCommand (WriteFileFileSystemCommand d) = d^.jsonrpcWriteFileFileSystemCommandData
+
 --------------------------------------------------------------------------------
 -- |
 --
@@ -1454,16 +1519,20 @@ data DomainData = DomainData {
   , _toolsDirDomainData          :: String
   , _promptsDirDomainData        :: String
   , _resourcesDirDomainData      :: String
+  , _sandboxDirDomainData       :: Maybe String
   , _requestQueueDomainData      :: TQueue McpRequest
   , _responseQueueDomainData     :: TQueue McpResponse
   , _notificationQueueDomainData :: TQueue McpNotification
   , _commandQueueDomainData      :: TQueue Command
   , _cmdRunQueueDomainData       :: TQueue CmdRunCommand
+  , _fileSystemQueueDomainData   :: TQueue FileSystemCommand
   , _watchQueueDomainData        :: TQueue WatchCommand
   , _procspawnQueueDomainData    :: TQueue ProcSpawnCommand
   , _socketQueueDomainData       :: TQueue SocketCommand
   , _serialQueueDomainData       :: TQueue SerialCommand
   , _promptsDomainData           :: [String]
+  , _invalidCharsDomainData      :: [String]
+  , _invalidCmdsDomainData       :: [String]
   }
 
 makeLenses ''DomainData
@@ -1484,6 +1553,7 @@ defaultDomainData = do
   notQ <- newTQueueIO
   cmdQ <- newTQueueIO
   cmdRunQ <- newTQueueIO
+  fileSystemQ <- newTQueueIO
   watchQ  <- newTQueueIO
   procQ   <- newTQueueIO
   socketQ   <- newTQueueIO
@@ -1494,16 +1564,20 @@ defaultDomainData = do
          , _toolsDirDomainData          = "pty-mcp-server/tools"
          , _promptsDirDomainData        = "pty-mcp-server/prompts"
          , _resourcesDirDomainData      = "pty-mcp-server/resources"
+         , _sandboxDirDomainData       = Nothing
          , _requestQueueDomainData      = reqQ
          , _responseQueueDomainData     = resQ
          , _notificationQueueDomainData = notQ
          , _commandQueueDomainData      = cmdQ
          , _cmdRunQueueDomainData       = cmdRunQ
+         , _fileSystemQueueDomainData   = fileSystemQ
          , _watchQueueDomainData        = watchQ
          , _procspawnQueueDomainData    = procQ
          , _socketQueueDomainData       = socketQ
          , _serialQueueDomainData       = serialQ
          , _promptsDomainData           = def
+         , _invalidCharsDomainData      = def
+         , _invalidCmdsDomainData       = def
          }
 
 -- |
